//More information at: https://www.aeq-web.com/
#include <ESP8266HTTPClient.h>
#include <ESP8266WiFi.h>
#include <Wire.h>
#include <Adafruit_Sensor.h>
#include <Adafruit_BME280.h>

//////////////////////////////////////////////////////////BASIC SETTINGS//////////////////////////////////////////////////////////
const char* wifi_ssid = "AEQ-NETWORK"; //WiFi Network Name
const char* wifi_key = "www.aeq-web.com"; //WiFi Network Key
uint8_t Wind_Pin = D3; //Define Anemometer Pin
const int m_time = 3; //Define meassure time for wind (s)
const char* server_url = "http://testserver.aeq-web.com/weatherstation/uplink.php";  //Define Url to PHP Server
//////////////////////////////////////////////////////////BASIC SETTINGS//////////////////////////////////////////////////////////

float temp;
float pressure;
float humidity;
float wind;
int wind_ct;

Adafruit_BME280 bme;
void setup() {

  Serial.begin(115200);
  if (!bme.begin())
  {
    Serial.println("BME 280 not found!");
  }
  WiFi.begin(wifi_ssid, wifi_key);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.println("Waiting for WiFi connection");
  }
}

void loop() {
  getSensorData();
  sendHttpData();
  delay(60000);
}

void getSensorData() {
  meassure_wind();
  temp = bme.readTemperature();
  pressure = bme.readPressure() / 100;
  humidity = bme.readHumidity();
  Serial.print("Temp: ");
  Serial.print(temp);
  Serial.print(" *C Pressure: ");
  Serial.print(pressure);
  Serial.print(" H/Pa Humidity: ");
  Serial.print(humidity);
  Serial.print(" % Wind: ");
  Serial.print(wind);
  Serial.println(" KM/h");
}

void meassure_wind() {
  wind_ct = 0;
  attachInterrupt(digitalPinToInterrupt(Wind_Pin), IntCallback, RISING);
  delay(1000 * m_time);
  wind = (float)wind_ct / (float)m_time * 2.4;
}

void IntCallback() {
  wind_ct++;
}

void sendHttpData() {
  if (WiFi.status() == WL_CONNECTED) {
    HTTPClient http;
    http.begin(server_url);
    http.addHeader("Content-Type", "application/x-www-form-urlencoded");
    String SendPost = "&wx=" + String(temp) + "~" + String(pressure) + "~" + String(humidity) + "~" + String(humidity) + "~" + String(millis() / 1000);
    int httpCode = http.POST(SendPost);
    String payload = http.getString();
    if(httpCode == 200){
      Serial.println("Connection successful!");
    }
    Serial.println(payload);
    http.end();
  } else {
    Serial.println("Error in WiFi connection");
  }
}


